package com.vendor.burn.model;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import com.vendor.burn.model.BurnContext;
import com.vendor.burn.model.define.IBurner;
import com.vendor.burn.model.devices.IDeviceSetting;
import com.vendor.burn.model.devices.IFileSystemSetting;
import com.vendor.burn.model.devices.burners.CommonBurner;
import com.vendor.burn.model.devices.burners.EmmcBurner;
import com.vendor.burn.model.devices.burners.PartitionBurner;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.util.Arrays;
import java.util.List;

public class FileSystem {
  public static final com.vendor.burn.model.FileSystem none = new com.vendor.burn.model.FileSystem("none");
  
  public static final com.vendor.burn.model.FileSystem yaffs = new com.vendor.burn.model.FileSystem("yaffs");
  
  public static final com.vendor.burn.model.FileSystem ext3 = new com.vendor.burn.model.FileSystem("ext3/4");
  
  public static final com.vendor.burn.model.FileSystem TAT32 = new com.vendor.burn.model.FileSystem("fat32");
  
  public static final com.vendor.burn.model.FileSystem squashFs = new com.vendor.burn.model.FileSystem("squashfs");
  
  public static final com.vendor.burn.model.FileSystem ubiFs = new com.vendor.burn.model.FileSystem("ubifs");
  
  public static final com.vendor.burn.model.FileSystem f2fs = new com.vendor.burn.model.FileSystem("f2fs");
  
  public static final com.vendor.burn.model.FileSystem erofs = new com.vendor.burn.model.FileSystem("erofs");
  
  private static com.vendor.burn.model.FileSystem[] items = new com.vendor.burn.model.FileSystem[] { none, yaffs, ext3, TAT32, squashFs, ubiFs, f2fs, erofs };
  
  private static final String YAFFSHEAD = "YFSS!V10";
  
  private String fileName;
  
  private FileSystem(String fileName) {
    this.fileName = fileName;
  }
  
  public String name() {
    return this.fileName;
  }
  
  public static String[] getItems() {
    return new String[] { none.name(), yaffs.name(), ext3.name(), TAT32.name(), squashFs
        .name(), f2fs.name(), erofs.name() };
  }
  
  public static String[] getItems(IBurner burner) {
    if (burner instanceof CommonBurner)
      return new String[] { none.name(), yaffs.name(), ubiFs.name(), ext3
          .name(), TAT32.name(), squashFs.name(), f2fs.name(), erofs.name() }; 
    if (burner instanceof EmmcBurner)
      return new String[] { none.name(), ext3.name(), TAT32.name(), squashFs.name(), f2fs.name(), erofs.name() }; 
    if (burner instanceof PartitionBurner)
      return new String[] { none.name(), yaffs.name(), ubiFs.name(), squashFs
          .name() }; 
    return getItems();
  }
  
  public static boolean isYaffsFile(IBurner burner, File file) throws IOException {
    if (isYaffsFile(file)) {
      if (burner == null)
        return false; 
      BurnContext burnContext = burner.getBurnContext();
      if (burnContext == null)
        return false; 
      IDeviceSetting deviceSetting = burnContext.getDeviceSetting();
      if (deviceSetting == null)
        return false; 
      IFileSystemSetting fileSystemSetting = deviceSetting.getFileSystemSetting();
      com.vendor.burn.model.FileSystem[] fileSystems = fileSystemSetting.getFileSystems(burner);
      List<com.vendor.burn.model.FileSystem> asList = Arrays.asList(fileSystems);
      if (asList.contains(yaffs))
        return true; 
    } 
    return false;
  }
  
  private static boolean isYaffsFile(File file) throws IOException {
    byte[] szYaffsMark = new byte[8];
    FileInputStream inputStream = null;
    try {
      inputStream = new FileInputStream(file);
      int read = inputStream.read(szYaffsMark);
      if (read != 8)
        return false; 
      String fileHead = new String(szYaffsMark, System.getProperty("file.encoding"));
      return fileHead.startsWith("YFSS!V10");
    } finally {
      try {
        if (inputStream != null)
          inputStream.close(); 
      } catch (Exception exception) {}
    } 
  }
  
  public static com.vendor.burn.model.FileSystem[] getFileSystems(Object type) {
    Class<? extends Object> class1 = (Class)type.getClass();
    return getFileSystems(class1);
  }
  
  public static com.vendor.burn.model.FileSystem[] getFileSystems(Class<?> type) {
    if (type == CommonBurner.class)
      return new com.vendor.burn.model.FileSystem[] { none, yaffs, ubiFs, ext3, TAT32, squashFs, f2fs, erofs }; 
    if (type == EmmcBurner.class)
      return new com.vendor.burn.model.FileSystem[] { none, ext3, TAT32, squashFs, f2fs, erofs }; 
    if (type == PartitionBurner.class)
      return new com.vendor.burn.model.FileSystem[] { none, yaffs, ubiFs, squashFs }; 
    return (com.vendor.burn.model.FileSystem[])items.clone();
  }
  
  public static com.vendor.burn.model.FileSystem valueOf(String name) {
    if (name == null)
      return null; 
    for (int i = 0; i < items.length; i++) {
      if (name.equalsIgnoreCase(items[i].name()))
        return items[i]; 
    } 
    if (name.equalsIgnoreCase("ext3") || name.equalsIgnoreCase("ext4") || name
      .equalsIgnoreCase("ext3/4"))
      return ext3; 
    return null;
  }
  
  public static com.vendor.burn.model.FileSystem[] values() {
    return (com.vendor.burn.model.FileSystem[])items.clone();
  }
}
